<?php
/*
 * All Theme Options for Caspiar theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

// Control core classes for avoid errors
if( class_exists( 'CSF' ) ) {

  // Set a unique slug-like ID
  $prefix = 'caspiar_csf_theme_options';

  // Create options
  CSF::createOptions( $prefix, array(
    'menu_title'      => CASPIAR_NAME . esc_html__( ' Options', 'caspiar' ),
    'menu_slug'       => sanitize_title(CASPIAR_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => CASPIAR_NAME .' <small>V-'. CASPIAR_VERSION .' by <a href="'. CASPIAR_BRAND_URL .'" target="_blank">'. CASPIAR_BRAND_NAME .'</a></small>',
  ) );

  // Brand
  CSF::createSection( $prefix, array(
    'name'     => 'theme_brand',
    'title'    => esc_html__( 'Logo', 'caspiar' ),
    'icon'     => 'fa fa-bookmark',
    'fields' => array(

      // Site Logo
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Site Logo', 'caspiar' ),
      ),
      array(
        'id'    => 'brand_logo_default',
        'type'  => 'media',
        'url'   => false,
        'title' => esc_html__( 'Logo', 'caspiar' ),
        'desc' => esc_html__( 'Upload your 2x size of logo here. It\'ll comfortable for retina screens.', 'caspiar' ),
        'button_title' => esc_html__( 'Add Logo', 'caspiar' ),
      ),
      array(
        'id'    => 'logo_width_height',
        'type'  => 'dimensions',
        'title'       => esc_html__( 'Logo Width & Height', 'caspiar' ),
        'unit'  => false,
      ),
      array(
        'id'    => 'brand_logo_top_bottom',
        'type'  => 'spacing',
        'title' => esc_html__( 'Logo Top & Bottom Space', 'caspiar' ),
        'left'  => false,
        'right' => false,
      ),

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__('Transparent Header', 'caspiar')
      ),
      array(
        'id'    => 'transparent_logo_default',
        'type'  => 'media',
        'url'   => false,
        'title' => esc_html__('Transparent Logo', 'caspiar'),
        'info'  => esc_html__('Upload your transparent header logo here. This logo is used in transparent header by enabled in each pages.', 'caspiar'),
        'add_title' => esc_html__('Add Transparent Logo', 'caspiar'),
      ),

      // WordPress Admin Logo
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'WordPress Admin Logo', 'caspiar' ),
      ),
      array(
        'id'    => 'brand_logo_wp',
        'type'  => 'media',
        'url'   => false,
        'title' => esc_html__( 'Login logo', 'caspiar' ),
        'desc' => esc_html__( 'Upload your WordPress login page logo here.', 'caspiar' ),
        'button_title' => esc_html__( 'Add Login logo', 'caspiar' ),
      ),

    )
  ) );

  // General
  CSF::createSection( $prefix, array(
    'name'     => 'theme_general',
    'title'    => esc_html__( 'General', 'caspiar' ),
    'icon'     => 'fa fa-wrench',
    'fields' => array(
      
      array(
        'id'       => 'sticky_header',
        'type'     => 'switcher',
        'title'    => esc_html__( 'Sticky Header', 'caspiar' ),
        'desc'     => esc_html__( 'Turn On if you want your naviagtion bar on sticky.', 'caspiar' ),
        'text_on'  => 'Yes',
        'text_off' => 'No',
        'default' => true,
      ),
      array(
        'id'       => 'sticky_footer',
        'type'     => 'switcher',
        'title'    => esc_html__( 'Sticky Footer', 'caspiar' ),
        'desc'     => esc_html__( 'If you turn this ON the footer will be sticky.', 'caspiar' ),
        'text_on'  => 'Yes',
        'text_off' => 'No',
        'default' => false,
      ),
      array(
        'id'       => 'theme_preloader',
        'type'     => 'switcher',
        'title'    => esc_html__( 'Preloader', 'caspiar' ),
        'desc'     => esc_html__( 'Turn off if you don\'t want preloader.', 'caspiar' ),
        'text_on'  => 'Yes',
        'text_off' => 'No',
      ),
      array(
        'id'       => 'theme_btotop',
        'type'     => 'switcher',
        'title'    => esc_html__( 'Back To Top', 'caspiar' ),
        'desc'     => esc_html__( 'Turn off if you don\'t want back to top button.', 'caspiar' ),
        'text_on'  => 'Yes',
        'text_off' => 'No',
        'default' => true,
      ),
      array(
        'id'          => 'mobile_breakpoint',
        'type'        => 'text',
        'title'       => esc_html__( 'Mobile Menu Breakpoint', 'caspiar' ),
        'desc' => esc_html__( 'Just put numeric value only. Like : 1199. Don\'t use px or any other units.', 'caspiar' ),
      ),
      array(
        'id'       => 'theme_img_resizer',
        'type'     => 'switcher',
        'title'    => esc_html__( 'Disable Image Resizer?', 'caspiar' ),
        'desc'     => esc_html__( 'Turn on if you don\'t want image resizer.', 'caspiar' ),
      ),

    )
  ) );

  // Header Parent
  CSF::createSection( $prefix, array(
    'id'     => 'theme_header_tab',
    'title'    => esc_html__( 'Header', 'caspiar' ),
    'icon'     => 'fa fa-bars',
  ) );

  // Design
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_header_tab',
    'name'     => 'header_design_tab',
    'title'    => esc_html__( 'Design', 'caspiar' ),
    'icon'     => 'fa fa-magic',
    'fields' => array(

      array(
        'id'           => 'select_header_design',
        'type'         => 'image_select',
        'title'        => esc_html__( 'Select Header Design', 'caspiar' ),
        'options'      => array(
          'style_one'    => CASPIAR_CS_IMAGES .'/hs-1.png',
          'style_two'    => CASPIAR_CS_IMAGES .'/hs-2.png',
          'style_three'    => CASPIAR_CS_IMAGES .'/hs-3.png',
        ),
        'attributes' => array(
          'data-depend-id' => 'header_design',
        ),
        'radio'        => true,
        'default'   => 'style_one',
        'info' => esc_html__( 'Select your header design, following options will may differ based on your selection of header design.', 'caspiar' ),
      ),
      array(
        'id'        => 'transparent_header',
        'type'      => 'select',
        'title'     => esc_html__( 'Transparent Header', 'caspiar' ),
        'options'   => array(
          'non-transparent' => 'Default',
          'transparent'   => 'Transparent',
        ),
        'dependency'   => array('select_header_design', '==', 'style_three'),
      ),
      array(
        'id'       => 'need_content',
        'type'     => 'switcher',
        'title' => esc_html__( 'Need Header Content', 'caspiar' ),
        'default' => true,
        'dependency'   => array('select_header_design', 'any', 'style_two,style_three'),
      ),
      array(
        'id'              => 'header_content',
        'title'           => esc_html__( 'Header Shortcode', 'caspiar' ),
        'desc'            => esc_html__( 'Add your header buttons here. Example : Buttons', 'caspiar' ),
        'type'            => 'textarea',
        'shortcoder'      => 'caspiar_vt_shortcodes',
        'dependency'   => array('need_content|select_header_design', '==|!=', 'true|style_one'),
      ),
      array(
        'id'              => 'wpml_shortcode',
        'title'           => esc_html__( 'WPML Shortcode', 'caspiar' ),
        'desc'            => esc_html__( 'Add your wpml shortcode here. Example : Wpml', 'caspiar' ),
        'type'            => 'textarea',
        'shortcoder'      => 'caspiar_vt_shortcodes',
      ),
      array(
        'id'        => 'search_icon',
        'type'      => 'select',
        'title'     => esc_html__( 'Search Icon', 'caspiar' ),
        'options'   => array(
          'hide'   => 'Hide',
          'show' => 'Show',
        ),
      ),
      array(
        'id'        => 'cart_icon',
        'type'      => 'select',
        'title'     => esc_html__( 'Cart Icon', 'caspiar' ),
        'options'   => array(
          'hide'   => 'Hide',
          'show' => 'Show',
        ),
      ),

    )
  ) );

  // Title Bar
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_header_tab',
    'name'     => 'header_banner_tab',
    'title'    => esc_html__( 'Title Bar (or) Banner', 'caspiar' ),
    'icon'     => 'fa fa-bullhorn',
    'fields' => array(

      array(
        'id'       => 'need_title_bar',
        'type'     => 'switcher',
        'title'   => esc_html__( 'Title Bar', 'caspiar' ),
        'desc'   => esc_html__( 'If you want title bar in your sub-pages, please turn this ON.', 'caspiar' ),
        'default'     => true,
      ),
      array(
        'id'             => 'title_bar_padding',
        'type'           => 'select',
        'title'          => esc_html__( 'Padding Spaces Top & Bottom', 'caspiar' ),
        'options'        => array(
          'padding-default' => esc_html__( 'Default Spacing', 'caspiar' ),
          'padding-xs' => esc_html__( 'Extra Small Padding', 'caspiar' ),
          'padding-sm' => esc_html__( 'Small Padding', 'caspiar' ),
          'padding-md' => esc_html__( 'Medium Padding', 'caspiar' ),
          'padding-lg' => esc_html__( 'Large Padding', 'caspiar' ),
          'padding-xl' => esc_html__( 'Extra Large Padding', 'caspiar' ),
          'padding-no' => esc_html__( 'No Padding', 'caspiar' ),
          'padding-custom' => esc_html__( 'Custom Padding', 'caspiar' ),
        ),
        'dependency'   => array( 'need_title_bar', '==', 'true' ),
      ),
      array(
        'id'    => 'titlebar_top_bottom_padding',
        'type'  => 'spacing',
        'title' => esc_html__( 'Title Bar Top & Bottom Space', 'caspiar' ),
        'left'  => false,
        'right' => false,
        'dependency'   => array( 'title_bar_padding|need_title_bar', '==|==', 'padding-custom|true' ),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Background Options', 'caspiar' ),
      ),

    
      array(
        'id'      => 'titlebar_bg',
        'type'    => 'background',
        'title'   => esc_html__( 'Background', 'caspiar' ),
        'background_color'      => true,
        'background_image'      => true,
        'background-position'   => true,
        'background_repeat'     => true,
        'background_attachment' => true,
        'background_size'       => true,
        'background_origin'     => true,
        'background_clip'       => true,
        'background_blend_mode' => true,
        'dependency' => array( 'need_title_bar', '==', 'true' ),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Breadcrumbs', 'caspiar' ),
      ),
      array(
        'id'      => 'need_breadcrumbs',
        'type'    => 'switcher',
        'title'   => esc_html__( 'Breadcrumbs', 'caspiar' ),
        'label'   => esc_html__( 'If you want Breadcrumbs in title bar, please turn this ON.', 'caspiar' ),
        'default'    => true,
      ),

    )
  ) );

  // Footer
  CSF::createSection( $prefix, array(
    'name'     => 'footer_section',
    'title'    => esc_html__( 'Footer', 'caspiar' ),
    'icon'     => 'fa fa-ellipsis-h',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Footer Widget Layout', 'caspiar' )
      ),
      array(
        'id'    => 'footer_widget_block',
        'type'  => 'switcher',
        'title' => esc_html__( 'Enable Widget Block', 'caspiar' ),
        'desc' => esc_html__( 'If you turn this ON, then Goto : Appearance > Widgets. There you can see Footer Widget 1,2,3 or 4 Widget Area, add your widgets there.', 'caspiar' ),
        'default' => true,
      ),
      array(
        'id'    => 'footer_widget_layout',
        'type'  => 'image_select',
        'title' => esc_html__( 'Widget Layouts', 'caspiar' ),
        'desc' => esc_html__( 'Choose your footer widget layouts.', 'caspiar' ),
        'options' => array(
          1   => CASPIAR_CS_IMAGES . '/footer/footer-1.png',
          2   => CASPIAR_CS_IMAGES . '/footer/footer-2.png',
          3   => CASPIAR_CS_IMAGES . '/footer/footer-3.png',
          4   => CASPIAR_CS_IMAGES . '/footer/footer-4.png',
          5   => CASPIAR_CS_IMAGES . '/footer/footer-5.png',
          6   => CASPIAR_CS_IMAGES . '/footer/footer-6.png',
          7   => CASPIAR_CS_IMAGES . '/footer/footer-7.png',
          8   => CASPIAR_CS_IMAGES . '/footer/footer-8.png',
          9   => CASPIAR_CS_IMAGES . '/footer/footer-9.png',
          10  => CASPIAR_CS_IMAGES . '/footer/footer-10.png',
        ),
        'default' => 8,
        'dependency'  => array('footer_widget_block', '==', 'true'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Footer Top', 'caspiar' )
      ),
      array(
        'id'        => 'curve_footer',
        'type'      => 'select',
        'title'     => esc_html__( 'Curve Footer', 'caspiar' ),
        'options'   => array(
          'hide'   => 'Hide',
          'show' => 'Show',
        ),
      ),
      array(
        'id'        => 'hide_footer_top',
        'type'      => 'select',
        'title'     => esc_html__( 'Footer Top Widget', 'caspiar' ),
        'options'   => array(
          'hide'   => 'Hide',
          'show' => 'Show',
        ),
      ),
      array(
        'id'            => 'footer_top_title',
        'type'          => 'text',
        'title'         => esc_html__( 'Title', 'caspiar' ),
        'desc'          => esc_html__( 'Enter your title.', 'caspiar' ),
        'dependency'  => array('hide_footer_top', '==', 'show'),
      ),
      array(
        'id'              => 'footer_top_btn_txt',
        'type'            => 'text',
        'title'           => esc_html__( 'Button Text', 'caspiar' ),
        'desc'            => esc_html__( 'Enter your button text.', 'caspiar' ),
        'dependency'  => array('hide_footer_top', '==', 'show'),
      ),
      array(
        'id'              => 'footer_top_btn_link',
        'title'           => esc_html__( 'Button Link', 'caspiar' ),
        'desc'            => esc_html__( 'Enter your button link.', 'caspiar' ),
        'type'            => 'text',
        'dependency'  => array('hide_footer_top', '==', 'show'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Copyright Layout', 'caspiar' )
      ),
      array(
        'id'    => 'need_copyright',
        'type'  => 'switcher',
        'title' => esc_html__( 'Enable Copyright Section', 'caspiar' ),
        'default' => true,
      ),
      array(
        'id'    => 'copyright_layout',
        'type'  => 'image_select',
        'title' => esc_html__( 'Select Copyright Layout', 'caspiar' ),
        'options'      => array(
          'copyright-1'    => CASPIAR_CS_IMAGES .'/footer/copyright-1.png',
          'copyright-2'    => CASPIAR_CS_IMAGES .'/footer/copyright-2.png',
          'copyright-3'    => CASPIAR_CS_IMAGES .'/footer/copyright-3.png',
          ),
        'default'      => 'copyright-1',
        'dependency'     => array('need_copyright', '==', 'true'),
      ),
      array(
        'id'              => 'copyright_text',
        'title'           => esc_html__( 'Copyright Text', 'caspiar' ),
        'desc'            => esc_html__( 'Helpful shortcodes: [caspiar_current_year] [caspiar_home_url] or any shortcode.', 'caspiar' ),
        'type'            => 'textarea',
        'shortcoder'      => 'caspiar_vt_shortcodes',
        'dependency'      => array('need_copyright', '==', 'true'),
      ),
      array(
        'id'              => 'copyright_text_right',
        'title'           => esc_html__( 'Copyright Right Text', 'caspiar' ),
        'desc'            => esc_html__( 'Add any shortcode.', 'caspiar' ),
        'type'            => 'textarea',
        'shortcoder'      => 'caspiar_vt_shortcodes',
        'dependency'   => array('need_copyright|copyright_layout', '==|!=', 'true|copyright-3'),
      ),

    )
  ) );

  // Design Parent
  CSF::createSection( $prefix, array(
    'id'     => 'theme_design',
    'title'    => esc_html__( 'Design', 'caspiar' ),
    'icon'     => 'fa fa-magic',
  ) );

  // Colors
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_design',
    'name'     => 'theme_color_section',
    'title'    => esc_html__( 'Colors', 'caspiar' ),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__( 'Color Options', 'caspiar' ),
      ),
      array(
        'type'    => 'content',
        'content' => esc_html__( 'All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer. Highly customizable colors are in Appearance > Customize', 'caspiar' ),
      ),

    )
  ) );

  // Typography
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_design',
    'name'     => 'theme_typo_section',
    'title'    => esc_html__( 'Typography', 'caspiar' ),
    'icon'     => 'fa fa-header',
    'fields' => array(

      array(
        'id'            => 'theme_typo',
        'type'          => 'accordion',
        'title'         => esc_html__( 'Typography', 'caspiar' ),
        'accordions'    => array(

          array(
            'title'     => esc_html__( 'Body Typography', 'caspiar' ),
            'fields'    => array(
              array(
                'id'                 => 'body_font',
                'type'               => 'typography',
                'title'              => esc_html__( 'Typography', 'caspiar' ),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Quicksand',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'body_css',
                'type'            => 'textarea',
                'title'           => esc_html__( 'Custom CSS', 'caspiar' ),
                'desc'            => esc_html__( 'Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'caspiar' ),
              ),
            )
          ),
          array(
            'title'     => esc_html__( 'Menu Typography', 'caspiar' ),
            'fields'    => array(
              array(
                'id'                 => 'menu_font',
                'type'               => 'typography',
                'title'              => esc_html__( 'Typography', 'caspiar' ),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Quicksand',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'menu_css',
                'type'            => 'textarea',
                'title'           => esc_html__( 'Custom CSS', 'caspiar' ),
                'desc'            => esc_html__( 'Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'caspiar' ),
              ),
            )
          ),
          array(
            'title'  => esc_html__( 'Sub Menu Typography', 'caspiar' ),
            'fields'    => array(
              array(
                'id'                 => 'sub_menu_font',
                'type'               => 'typography',
                'title'              => esc_html__( 'Typography', 'caspiar' ),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Quicksand',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'sub_menu_css',
                'type'            => 'textarea',
                'title'           => esc_html__( 'Custom CSS', 'caspiar' ),
                'desc'            => esc_html__( 'Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'caspiar' ),
              ),
            )
          ),
          array(
            'title'  => esc_html__( 'Headings Typography', 'caspiar' ),
            'fields'    => array(
              array(
                'id'                 => 'headings_font',
                'type'               => 'typography',
                'title'              => esc_html__( 'Typography', 'caspiar' ),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Quicksand',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'headings_css',
                'type'            => 'textarea',
                'title'           => esc_html__( 'Custom CSS', 'caspiar' ),
                'desc'            => esc_html__( 'Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'caspiar' ),
              ),
            )
          ),
          array(
            'title'  => esc_html__( 'Shortcode Elements Primary Font', 'caspiar' ),
            'fields'    => array(
              array(
                'id'                 => 'shortcode_prime_font',
                'type'               => 'typography',
                'title'              => esc_html__( 'Typography', 'caspiar' ),
                'font_family'        => true,
                'font_weight'        => true,
                'font_style'         => true,
                'font_size'          => true,
                'line_height'        => true,
                'letter_spacing'     => true,
                'text_align'         => true,
                'text-transform'     => true,
                'color'              => true,
                'subset'             => true,
                'backup_font_family' => true,
                'font_variant'       => true,
                'word_spacing'       => true,
                'text_decoration'    => true,
                'default'            => array(
                  'font-family'      => 'Nunito Sans',
                  'type'             => 'google',
                ),
              ),
              array(
                'id'              => 'shortcode_prime_css',
                'type'            => 'textarea',
                'title'           => esc_html__( 'Custom CSS', 'caspiar' ),
                'desc'            => esc_html__( 'Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'caspiar' ),
              ),
            )
          ),

        )
      ),

      array(
        'id'        => 'custom_typography',
        'type'      => 'group',
        'title'     => esc_html__( 'Custom Typography', 'caspiar' ),
        'fields'    => array(
          array(
            'id'    => 'custom_title',
            'type'  => 'text',
            'title' => esc_html__( 'Title', 'caspiar' ),
          ),
          array(
            'id'                 => 'custom_typo',
            'type'               => 'typography',
            'title'              => esc_html__( 'Typography', 'caspiar' ),
            'font_family'        => true,
            'font_weight'        => true,
            'font_style'         => true,
            'font_size'          => true,
            'line_height'        => true,
            'letter_spacing'     => true,
            'text_align'         => true,
            'text-transform'     => true,
            'color'              => true,
            'subset'             => true,
            'backup_font_family' => true,
            'font_variant'       => true,
            'word_spacing'       => true,
            'text_decoration'    => true,
            'default'            => array(
              'font-family'      => 'Noto Sans',
              'type'             => 'google',
            ),
          ),
          array(
            'id'              => 'custom_css',
            'type'            => 'textarea',
            'title'           => esc_html__( 'Custom CSS', 'caspiar' ),
            'desc'            => esc_html__( 'Enter your Custom CSS separated with ( , ) Ex: .class1, .class2', 'caspiar' ),
          ),
        ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'custom_font_family',
        'type'               => 'group',
        'title'              => esc_html__( 'Upload Custom Fonts', 'caspiar' ),
        'button_title'       => esc_html__( 'Add New Custom Font', 'caspiar' ),
        'accordion_title'    => esc_html__( 'Adding New Font', 'caspiar' ),
        'accordion'          => true,
        'desc'               => esc_html__( 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!', 'caspiar' ),
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => esc_html__( 'Font-Family Name', 'caspiar' ),
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),

          array(
            'id'            => 'weight',
            'type'          => 'select',
            'title'         => esc_html__( 'Font Weight', 'caspiar' ),
            'options'       => array(
              '100'         => esc_html__( 'Thin 100', 'caspiar' ),
              '100italic'   => esc_html__( 'Thin 100 Italic', 'caspiar' ),
              '200'         => esc_html__( 'Extra Light 200', 'caspiar' ),
              '200italic'   => esc_html__( 'Extra Light 200 Italic', 'caspiar' ),
              '300'         => esc_html__( 'Light 300', 'caspiar' ),
              '300italic'   => esc_html__( 'Light 300 Italic', 'caspiar' ),
              '400'         => esc_html__( 'Regular 400', 'caspiar' ),
              '400italic'   => esc_html__( 'Regular 400 Italic', 'caspiar' ),
              '500'         => esc_html__( 'Medium 500', 'caspiar' ),
              '500italic'   => esc_html__( 'Medium 500 Italic', 'caspiar' ),
              '600'         => esc_html__( 'Semi Bold 600', 'caspiar' ),
              '600italic'   => esc_html__( 'Semi Bold 600 Italic', 'caspiar' ),
              '700'         => esc_html__( 'Bold 700', 'caspiar' ),
              '700italic'   => esc_html__( 'Bold 700 Italic', 'caspiar' ),
              '800'         => esc_html__( 'Extra Bold 800', 'caspiar' ),
              '800italic'   => esc_html__( 'Extra Bold 800 Italic', 'caspiar' ),
              '900'         => esc_html__( 'Black 900', 'caspiar' ),
              '900italic'   => esc_html__( 'Black 900 Italic', 'caspiar' ),
            ),
            'placeholder'   => esc_html__( 'Select font weight', 'caspiar' ),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => 'Upload .ttf <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.ttf</i>',
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => 'Upload .eot <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.eot</i>',
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => 'Upload .otf <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.otf</i>',
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => 'Upload .woff <small><i>(optional)</i></small>',
            'library'        => 'font',
            'button_title'   => 'Upload <i>.woff</i>',
          ),

          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => 'Extra CSS Style <small><i>(optional)</i></small>',
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field

    )
  ) );

  // Post Parent
  CSF::createSection( $prefix, array(
    'id'       => 'theme_post_types',
    'title'    => esc_html__( 'Custom Post Types', 'caspiar' ),
    'icon'     => 'fa fa-files-o',
  ) );
  
  // Case Studies
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_post_types',
    'name'     => 'case_studies_section',
    'title'    => esc_html__( 'Case Studies', 'caspiar' ),
    'icon'     => 'fa fa-briefcase',
    'fields'   => array(

      // Case Studies Name
      array(
        'id'            => 'noneed_case_studies_post',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Disable Case Studies Post?', 'caspiar' ),
        'desc'          => esc_html__( 'If need to disable this post type, please turn this ON.', 'caspiar' ),
        'default'       => false,
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Name Change', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_case_studies_name',
        'type'          => 'text',
        'title'         => esc_html__( 'Case Studies Name', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'Case Studies'
        ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_case_studies_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Case Studies Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'casestudies-item'
        ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_case_studies_cat_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Case Studies Category Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'casestudies-category'
        ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'danger',
        'content'       => esc_html__( 'Important: Please do not set case studies slug and page slug as same. It\'ll not work.', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      // Case Studies Name
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Case Studies Listing & Style', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'             => 'case_studies_style',
        'type'           => 'select',
        'title'          => esc_html__( 'Case Studies Style', 'caspiar' ),
        'options'        => array(
          'one'          => esc_html__( 'Style One', 'caspiar' ),
          'two'          => esc_html__( 'Style Two', 'caspiar' ),
        ),
        'placeholder' => esc_html__( 'Select case studies style', 'caspiar' ),
        'dependency'   => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'             => 'case_studies_col',
        'type'           => 'select',
        'title'          => esc_html__( 'Case Studies Column', 'caspiar' ),
        'options'        => array(
          'three'          => esc_html__( 'Three', 'caspiar' ),
          'four'          => esc_html__( 'Four', 'caspiar' ),
        ),
        'placeholder' => esc_html__( 'Select Column', 'caspiar' ),
        'dependency'   => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_limit',
        'type'          => 'spinner',
        'title'         => esc_html__( 'Case Studies Limit', 'caspiar' ),
        'subtitle'      => esc_html__( 'max:100 | min:-1 | step:1', 'caspiar' ),
        'max'           => 100,
        'min'           => -1,
        'step'          => 1,
        'default'       => 9,
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_show_category',
        'type'          => 'select',
        'title'         => esc_html__( 'Case Studies Categories', 'caspiar' ),
        'desc'          => esc_html__( 'Select categories you want to display.', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
        'chosen'        => true,
        'multiple'      => true,
        'attributes'    => array(
          'style'       => 'width: 200px;'
        ),
        'options'       => 'categories',
        'query_args'  => array(
          'type'      => 'casestudies',
          'taxonomy'  => 'casestudies_category',
        ),
        'placeholder'   => esc_html__( 'Select categories', 'caspiar' ),
      ),
      array(
        'id'            => 'case_studies_orderby',
        'type'          => 'select',
        'title'         => esc_html__( 'Order By', 'caspiar' ),
        'options'       => array(
          'none'        => esc_html__( 'None', 'caspiar' ),
          'ID'          => esc_html__( 'ID', 'caspiar' ),
          'author'      => esc_html__( 'Author', 'caspiar' ),
          'title'       => esc_html__( 'Title', 'caspiar' ),
          'date'        => esc_html__( 'Date', 'caspiar' ),
          'name'        => esc_html__( 'Name', 'caspiar' ),
          'modified'    => esc_html__( 'Modified', 'caspiar' ),
          'rand'        => esc_html__( 'Random', 'caspiar' ),
          'menu_order'  => esc_html__( 'Menu Order', 'caspiar' ),
        ),
        'placeholder'   => esc_html__( 'Select Case Studies Order By', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_order',
        'type'          => 'select',
        'title'         => esc_html__( 'Order', 'caspiar' ),
        'options'       => array(
          'ASC'         => esc_html__( 'Asending', 'caspiar' ),
          'DESC'        => esc_html__( 'Desending', 'caspiar' ),
        ),
        'placeholder'   => esc_html__( 'Select Case Studies Order', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Enable/Disable Options', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_aqr',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Disable Image Resize?', 'caspiar' ),
        'desc'          => esc_html__( 'If need to disable image resize, please turn this ON.', 'caspiar' ),
        'default'       => false,
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_pagination',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Pagination', 'caspiar' ),
        'desc'          => esc_html__( 'If you need pagination in case studies pages, please turn this ON.', 'caspiar' ),
        'default'       => true,
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),

      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Case Studies Single', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_single_pagination',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Single Pagination', 'caspiar' ),
        'desc'          => esc_html__( 'If you need pagination in case studies single pages, please turn this ON.', 'caspiar' ),
        'default'       => true,
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'            => 'case_studies_single_url',
        'type'          => 'text',
        'title'         => esc_html__( 'Case Studies Home URL', 'caspiar' ),
        'desc'          => esc_html__( 'Enter single URL.', 'caspiar' ),
        'dependency'    => array('noneed_case_studies_post', '==', 'false'),
      ),
      array(
        'id'          => 'prev_case_studies',
        'type'        => 'text',
        'title'       => esc_html__( 'Case Studies Prev Text', 'caspiar' ),
      ),
      array(
        'id'          => 'next_case_studies',
        'type'        => 'text',
        'title'       => esc_html__( 'Case Studies Next Text', 'caspiar' ),
      ),

    )
  ) );

  // Testimonial
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_post_types',
    'name'     => 'testimonial_section',
    'title'    => esc_html__( 'Testimonial', 'caspiar' ),
    'icon'     => 'fa fa-commenting',
    'fields'   => array(

      // Testimonial Name
      array(
        'id'            => 'noneed_testimonial_post',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Disable Testimonial Post?', 'caspiar' ),
        'desc'          => esc_html__( 'If need to disable this post type, please turn this ON.', 'caspiar' ),
        'default'       => false,
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Name Change', 'caspiar' ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_testimonial_name',
        'type'          => 'text',
        'title'         => esc_html__( 'Testimonial Name', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'Testimonial'
        ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_testimonial_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Testimonial Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'testimonial-item'
        ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_testimonial_cat_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Testimonial Category Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'testimonial-category'
        ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'danger',
        'content'       => esc_html__( 'Important: Please do not set testimonial slug and page slug as same. It\'ll not work.', 'caspiar' ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      // Testimonial Name
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Testimonial Listing & Style', 'caspiar' ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'testimonial_limit',
        'type'          => 'spinner',
        'title'         => 'Testimonial Limit',
        'subtitle'      => 'max:100 | min:-1 | step:1',
        'max'           => 100,
        'min'           => -1,
        'step'          => 1,
        'default'       => 9,
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'testimonial_orderby',
        'type'          => 'select',
        'title'         => esc_html__( 'Order By', 'caspiar' ),
        'options'       => array(
          'none'        => esc_html__( 'None', 'caspiar' ),
          'ID'          => esc_html__( 'ID', 'caspiar' ),
          'author'      => esc_html__( 'Author', 'caspiar' ),
          'title'       => esc_html__( 'Title', 'caspiar' ),
          'date'        => esc_html__( 'Date', 'caspiar' ),
          'name'        => esc_html__( 'Name', 'caspiar' ),
          'modified'    => esc_html__( 'Modified', 'caspiar' ),
          'rand'        => esc_html__( 'Random', 'caspiar' ),
          'menu_order'  => esc_html__( 'Menu Order', 'caspiar' ),
        ),
        'placeholder'   => esc_html__( 'Select Testimonial Order By', 'caspiar' ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),
      array(
        'id'            => 'testimonial_order',
        'type'          => 'select',
        'title'         => esc_html__( 'Order', 'caspiar' ),
        'options'       => array(
          'ASC'         => esc_html__( 'Asending', 'caspiar' ),
          'DESC'        => esc_html__( 'Desending', 'caspiar' ),
        ),
        'placeholder'   => esc_html__( 'Select Testimonial Order', 'caspiar' ),
        'dependency'    => array('noneed_testimonial_post', '==', 'false'),
      ),

    )
  ) );

  // Team
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_post_types',
    'name'     => 'team_section',
    'title'    => esc_html__( 'Team', 'caspiar' ),
    'icon'     => 'fa fa-users',
    'fields'   => array(

      // Team Name
      array(
        'id'            => 'noneed_team_post',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Disable Team Post?', 'caspiar' ),
        'desc'          => esc_html__( 'If need to disable this post type, please turn this ON.', 'caspiar' ),
        'default'       => false,
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Name Change', 'caspiar' ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_team_name',
        'type'          => 'text',
        'title'         => esc_html__( 'Team Name', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'Team'
        ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_team_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Team Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'team-item'
        ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'theme_team_cat_slug',
        'type'          => 'text',
        'title'         => esc_html__( 'Team Category Slug', 'caspiar' ),
        'attributes'    => array(
          'placeholder' => 'team-category'
        ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'type'          => 'submessage',
        'style'         => 'danger',
        'content'       => esc_html__( 'Important: Please do not set team slug and page slug as same. It\'ll not work.', 'caspiar' ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      // Team Name
      array(
        'type'          => 'submessage',
        'style'         => 'info',
        'content'       => esc_html__( 'Team Listing & Style', 'caspiar' ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_limit',
        'type'          => 'spinner',
        'title'         => esc_html__( 'Team Limit', 'caspiar' ),
        'subtitle'      => esc_html__( 'max:100 | min:-1 | step:1', 'caspiar' ),
        'max'           => 100,
        'min'           => -1,
        'step'          => 1,
        'default'       => 9,
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_orderby',
        'type'          => 'select',
        'title'         => esc_html__( 'Order By', 'caspiar' ),
        'options'       => array(
          'none'        => esc_html__( 'None', 'caspiar' ),
          'ID'          => esc_html__( 'ID', 'caspiar' ),
          'author'      => esc_html__( 'Author', 'caspiar' ),
          'title'       => esc_html__( 'Title', 'caspiar' ),
          'date'        => esc_html__( 'Date', 'caspiar' ),
          'name'        => esc_html__( 'Name', 'caspiar' ),
          'modified'    => esc_html__( 'Modified', 'caspiar' ),
          'rand'        => esc_html__( 'Random', 'caspiar' ),
          'menu_order'  => esc_html__( 'Menu Order', 'caspiar' ),
        ),
        'placeholder'   => esc_html__( 'Select Team Order By', 'caspiar' ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_order',
        'type'          => 'select',
        'title'         => esc_html__( 'Order', 'caspiar' ),
        'options'       => array(
          'ASC'         => esc_html__( 'Asending', 'caspiar' ),
          'DESC'        => esc_html__( 'Desending', 'caspiar' ),
        ),
        'placeholder'   => esc_html__( 'Select Team Order', 'caspiar' ),
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_aqr',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Disable Image Resize?', 'caspiar' ),
        'desc'          => esc_html__( 'If need to disable image resize, please turn this ON.', 'caspiar' ),
        'default'       => false,
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),
      array(
        'id'            => 'team_pagination',
        'type'          => 'switcher',
        'title'         => esc_html__( 'Pagination', 'caspiar' ),
        'desc'          => esc_html__( 'If you need pagination in team pages, please turn this ON.', 'caspiar' ),
        'default'       => true,
        'dependency'    => array('noneed_team_post', '==', 'false'),
      ),

    )
  ) );

  // Blog
  CSF::createSection( $prefix, array(
    'id'       => 'blog_section',
    'title'    => esc_html__( 'Blog', 'caspiar' ),
    'icon'     => 'fa fa-edit',
  ) );

  // General
  CSF::createSection( $prefix, array(
    'parent'   => 'blog_section',
    'name'     => 'blog_general_tab',
    'title'    => esc_html__( 'General', 'caspiar' ),
    'icon'     => 'fa fa-cog',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Layout', 'caspiar' )
      ),      
      array(
        'id'             => 'blog_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__( 'Sidebar Position', 'caspiar' ),
        'options'        => array(
          'sidebar-right' => esc_html__( 'Right', 'caspiar' ),
          'sidebar-left' => esc_html__( 'Left', 'caspiar' ),
          'sidebar-hide' => esc_html__( 'Hide', 'caspiar' ),
        ),
        'placeholder' => 'Select sidebar position',
        'help'          => esc_html__( 'This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'caspiar' ),
        'desc'          => esc_html__( 'Default option : Right', 'caspiar' ),
      ),
      array(
        'id'             => 'blog_widget',
        'type'           => 'select',
        'title'          => esc_html__( 'Sidebar Widget', 'caspiar' ),
        'options'        => 'sidebars',
        'placeholder'    => esc_html__( 'Select Widget', 'caspiar' ),
        'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
        'desc'           => esc_html__( 'Default option : Main Widget Area', 'caspiar' ),
      ),
      array(
        'id'             => 'sidebar_type',
        'type'           => 'select',
        'title'          => esc_html__( 'Sidebar Style', 'caspiar' ),
        'options'        => array(
          'normal'       => esc_html__( 'Normal', 'caspiar' ),
          'bar-sticky'   => esc_html__( 'Sticky', 'caspiar' ),
          'bar-float'    => esc_html__( 'Floating', 'caspiar' ),
        ),
        'placeholder' => 'Select sidebar Style',
        'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Global Options', 'caspiar' )
      ),
      array(
        'id'         => 'theme_exclude_categories',
        'type'       => 'checkbox',
        'title'      => esc_html__( 'Exclude Categories', 'caspiar' ),
        'desc'      => esc_html__( 'Select categories you want to exclude from blog page.', 'caspiar' ),
        'options'    => 'categories',
      ),
      array(
        'id'            => 'theme_blog_excerpt',
        'type'          => 'spinner',
        'title'         => esc_html__( 'Excerpt Length', 'caspiar' ),
        'subtitle'      => esc_html__( 'max:200 | min:0 | step:1', 'caspiar' ),
        'max'           => 200,
        'min'           => 0,
        'step'          => 1,
        'default'       => 35,
      ),
      array(
        'id'      => 'theme_metas_hide',
        'type'    => 'checkbox',
        'title'   => esc_html__( 'Meta\'s to hide in listing', 'caspiar' ),
        'desc'    => esc_html__( 'Check items you want to hide from blog/post meta field.', 'caspiar' ),
        'inline'  => true,
        'options'    => array(
          'category'   => esc_html__( 'Category', 'caspiar' ),
          'date'    => esc_html__( 'Date', 'caspiar' ),
          'author'    => esc_html__( 'Author', 'caspiar' ),
        ),
      ),
      array(
        'id'        => "blog_date_format",
        'type'      => 'text',
        'title'     => esc_html__( 'Date Format', 'caspiar' ),
        'desc'      => 'Enter date format (for more info <a href="https://codex.wordpress.org/Formatting_Date_and_Time" target="_blank">click here</a>)',
      ),

    )
  ) );

  // Single
  CSF::createSection( $prefix, array(
    'parent'   => 'blog_section',
    'name'     => 'blog_single_tab',
    'title'    => esc_html__( 'Single', 'caspiar' ),
    'icon'     => 'fa fa-sticky-note',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Enable / Disable', 'caspiar' )
      ),
      array(
        'id'      => 'theme_single_metas_hide',
        'type'    => 'checkbox',
        'title'   => esc_html__( 'Meta\'s to hide in single', 'caspiar' ),
        'desc'    => esc_html__( 'Check items you want to hide from blog/post meta field.', 'caspiar' ),
        'inline'  => true,
        'options'    => array(
          'date'    => esc_html__( 'Date', 'caspiar' ),
          'category'   => esc_html__( 'Category', 'caspiar' ),
          'tag'   => esc_html__( 'Tag', 'caspiar' ),
          'share'    => esc_html__( 'Share', 'caspiar' ),
          'author'     => esc_html__( 'Author', 'caspiar' ),
        ),
      ),
      array(
        'id'    => 'single_featured_img',
        'type'  => 'switcher',
        'title' => esc_html__( 'Featured Image', 'caspiar' ),
        'desc' => esc_html__( 'If need to hide featured image on single blog page, please turn this ON.', 'caspiar' ),
      ),
      array(
        'id'        => 'blog_single_featured_img_type',
        'type'      => 'select',
        'title'     => esc_html__('Featured Image Display Type', 'caspiar'),
        'options'   => array(
          'banner' => 'Banner',
          'original' => 'Original',
        ),
        'dependency'     => array('single_featured_img', '!=', 'true'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Related Posts', 'caspiar' )
      ),
      array(
        'id'    => 'single_related_post',
        'type'  => 'switcher',
        'title' => esc_html__( 'Related Posts', 'caspiar' ),
        'desc' => esc_html__( 'If need to hide related posts on single blog page, please turn this OFF.', 'caspiar' ),
        'default' => true,
      ),
      array(
        'id'      => 'single_related_title',
        'type'    => 'text',
        'title'   => esc_html__( 'Section Title', 'caspiar' ),
        'desc'   => esc_html__( 'Related post section title.', 'caspiar' ),
        'dependency'     => array('single_related_post', '==', 'true'),
      ),
      array(
        'id'            => 'single_related_limit',
        'type'          => 'spinner',
        'title'         => esc_html__( 'Excerpt Length', 'caspiar' ),
        'subtitle'      => esc_html__( 'max:100 | min:0 | step:1', 'caspiar' ),
        'max'           => 100,
        'min'           => 0,
        'step'          => 1,
        'default'       => 2,
        'dependency'     => array('single_related_post', '==', 'true'),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Sidebar', 'caspiar' )
      ),
      array(
        'id'             => 'single_sidebar_position',
        'type'           => 'select',
        'title'          => esc_html__( 'Sidebar Position', 'caspiar' ),
        'options'        => array(
          'sidebar-right' => esc_html__( 'Right', 'caspiar' ),
          'sidebar-left' => esc_html__( 'Left', 'caspiar' ),
          'sidebar-hide' => esc_html__( 'Hide', 'caspiar' ),
        ),
        'placeholder' => 'Select sidebar position',
        'desc'          => esc_html__( 'Default option : Right', 'caspiar' ),
      ),
      array(
        'id'             => 'single_blog_widget',
        'type'           => 'select',
        'title'          => esc_html__( 'Sidebar Widget', 'caspiar' ),
        'options'        => 'sidebars',
        'placeholder'    => esc_html__( 'Select Widget', 'caspiar' ),
        'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
        'desc'           => esc_html__( 'Default option : Main Widget Area', 'caspiar' ),
      ),
      array(
        'id'             => 'single_sidebar_type',
        'type'           => 'select',
        'title'          => esc_html__( 'Sidebar Style', 'caspiar' ),
        'options'        => array(
          'normal'       => esc_html__( 'Normal', 'caspiar' ),
          'bar-sticky'   => esc_html__( 'Sticky', 'caspiar' ),
          'bar-float'    => esc_html__( 'Floating', 'caspiar' ),
        ),
        'placeholder' => 'Select sidebar Style',
        'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
      ),

    )
  ) );

  if (class_exists( 'WooCommerce' )) {
    // Woocommerce
    CSF::createSection( $prefix, array(
      'name'     => 'woocommerce_section',
      'title'    => esc_html__( 'Woocommerce', 'caspiar' ),
      'icon'     => 'fa fa-shopping-cart',
      'fields' => array(

        array(
          'type'    => 'submessage',
          'style'   => 'info',
          'content' => esc_html__( 'Layout', 'caspiar' )
        ),
        array(
          'id'             => 'woo_product_columns',
          'type'           => 'select',
          'title'          => esc_html__( 'Product Column', 'caspiar' ),
          'options'        => array(
            3 => esc_html__( 'Three Column', 'caspiar' ),
            4 => esc_html__( 'Four Column', 'caspiar' ),
          ),
          'placeholder' => esc_html__( 'Select Product Columns', 'caspiar' ),
          'help'          => esc_html__( 'This style will apply, default woocommerce listings pages. Like, shop and archive pages.', 'caspiar' ),
        ),
        array(
          'id'             => 'woo_sidebar_position',
          'type'           => 'select',
          'title'          => esc_html__( 'Sidebar Position', 'caspiar' ),
          'options'        => array(
            'right-sidebar' => esc_html__( 'Right', 'caspiar' ),
            'left-sidebar' => esc_html__( 'Left', 'caspiar' ),
            'sidebar-hide' => esc_html__( 'Hide', 'caspiar' ),
          ),
          'placeholder' => esc_html__( 'Select sidebar position', 'caspiar' ),
          'desc'          => esc_html__( 'Default option : Right', 'caspiar' ),
        ),
        array(
          'id'             => 'woo_widget',
          'type'           => 'select',
          'title'          => esc_html__( 'Sidebar Widget', 'caspiar' ),
          'options'        => 'sidebars',
          'placeholder' => esc_html__( 'Select Widget', 'caspiar' ),
          'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
          'desc'           => esc_html__( 'Default option : Main Widget Area', 'caspiar' ),
        ),
        array(
          'id'             => 'woo_sidebar_type',
          'type'           => 'select',
          'title'          => esc_html__( 'Sidebar Style', 'caspiar' ),
          'options'        => array(
            'normal'       => esc_html__( 'Normal', 'caspiar' ),
            'bar-sticky'   => esc_html__( 'Sticky', 'caspiar' ),
            'bar-float'    => esc_html__( 'Floating', 'caspiar' ),
          ),
          'placeholder' => 'Select sidebar Style',
          'dependency'     => array('woo_sidebar_position', '!=', 'sidebar-hide'),
        ),
        array(
          'type'    => 'submessage',
          'style'   => 'info',
          'content' => esc_html__( 'Single Product', 'caspiar' )
        ),
        array(
          'id'    => 'woo_single_related',
          'type'  => 'switcher',
          'title' => esc_html__( 'Related Products', 'caspiar' ),
          'desc' => esc_html__( 'If you want \'Related Products\' in single product page, please turn this ON.', 'caspiar' ),
          'default' => false,
        ),
        array(
          'id'             => 'woo_related_limit',
          'type'           => 'text',
          'title'          => esc_html__( 'Related Products Limit', 'caspiar' ),
          'dependency'     => array('woo_single_related', '==', 'true'),
        ),
        array(
          'id'             => 'woo_related_title',
          'type'           => 'text',
          'title'          => esc_html__( 'Related Products Title', 'caspiar' ),
          'dependency'     => array('woo_single_related', '==', 'true'),
        ),
        array(
          'id'    => 'woo_single_upsell',
          'type'  => 'switcher',
          'title' => esc_html__( 'You May Also Like(Upsell)', 'caspiar' ),
          'desc' => esc_html__( 'If you want \'You May Also Like\' products in single product page, please turn this ON.', 'caspiar' ),
          'default' => false,
        ),
        array(
          'id'    => 'woo_single_crosssell',
          'type'  => 'switcher',
          'title' => esc_html__( 'You May interested in(Cross Sell)', 'caspiar' ),
          'desc' => esc_html__( 'If you want \'You May interested in\' products in cart page, please turn this ON.', 'caspiar' ),
          'default' => false,
        ),

      )
    ) );
  }

  // Extra Pages Parent
  CSF::createSection( $prefix, array(
    'id'       => 'theme_extra_pages',
    'title'    => esc_html__( 'Extra Pages', 'caspiar' ),
    'icon'     => 'fa fa-clone',
  ) );

  // 404
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_extra_pages',
    'name'     => 'error_page_section',
    'title'    => esc_html__( '404 Page', 'caspiar' ),
    'icon'     => 'fa fa-exclamation-triangle',
    'fields' => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( '404 Error Page Options', 'caspiar' )
      ),
      array(
        'id'    => 'error_heading',
        'type'  => 'text',
        'title' => esc_html__( '404 Page Heading', 'caspiar' ),
        'desc'  => esc_html__( 'Enter 404 page heading.', 'caspiar' ),
      ),
      array(
        'id'    => 'error_sub_heading',
        'type'  => 'text',
        'title' => esc_html__( '404 Page Sub Heading', 'caspiar' ),
        'desc'  => esc_html__( 'Enter 404 page sub heading.', 'caspiar' ),
      ),
      array(
        'id'    => 'error_page_content',
        'type'  => 'textarea',
        'title' => esc_html__( '404 Page Content', 'caspiar' ),
        'desc'  => esc_html__( 'Enter 404 page content.', 'caspiar' ),
        'shortcoder'      => 'caspiar_vt_shortcodes',
      ),
      array(
        'id'    => 'error_page_bg',
        'type'  => 'media',
        'url'   => false,
        'title' => esc_html__( '404 Page Background', 'caspiar' ),
        'desc'  => esc_html__( 'Choose 404 page background image.', 'caspiar' ),
        'button_title' => esc_html__( 'Add 404 Image', 'caspiar' ),
      ),
      array(
        'id'    => 'error_btn_text',
        'type'  => 'text',
        'title' => esc_html__( 'Button Text', 'caspiar' ),
        'desc'  => esc_html__( 'Enter BACK TO HOME button text. If you want to change it.', 'caspiar' ),
      ),

    )
  ) );

  // Maintenance
  CSF::createSection( $prefix, array(
    'parent'   => 'theme_extra_pages',
    'name'     => 'maintenance_mode_section',
    'title'    => esc_html__( 'Maintenance Mode', 'caspiar' ),
    'icon'     => 'fa fa-hourglass-half',
    'fields'   => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : Maintenance Mode Page', 'caspiar' )
      ),
      array(
        'id'    => 'enable_maintenance_mode',
        'type'  => 'switcher',
        'title' => esc_html__( 'Maintenance Mode', 'caspiar' ),
        'default' => false,
      ),
      array(
        'id'    => 'elementor_page',
        'type'  => 'switcher',
        'title' => esc_html__( 'Elementor Page', 'caspiar' ),
        'desc'  => esc_html__( 'Enable if your selected page is edited by elementor.', 'caspiar' ),
        'default' => false,
        'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
      ),
      array(
        'id'             => 'maintenance_mode_page',
        'type'           => 'select',
        'title'          => esc_html__( 'Maintenance Mode Page', 'caspiar' ),
        'options'        => 'pages',
        'placeholder'    => esc_html__( 'Select a page', 'caspiar' ),
        'dependency'     => array( 'enable_maintenance_mode', '==', 'true' ),
      ),

    )
  ) );

  // Misc Parent
  CSF::createSection( $prefix, array(
    'id'       => 'misc_section',
    'title'    => esc_html__( 'Misc', 'caspiar' ),
    'icon'     => 'fa fa-recycle',
  ) );

  // Custom Sidebar
  CSF::createSection( $prefix, array(
    'parent'   => 'misc_section',
    'name'     => 'custom_sidebar_section',
    'title'    => esc_html__( 'Custom Sidebar', 'caspiar' ),
    'icon'     => 'fa fa-reorder',
    'fields'   => array(

      array(
        'id'     => 'custom_sidebar',
        'type'   => 'group',
        'title'           => esc_html__( 'Sidebars', 'caspiar' ),
        'subtitle'        => esc_html__( 'Go to Appearance -> Widgets after create sidebars', 'caspiar' ),
        'button_title'    => esc_html__( 'Add New Sidebar', 'caspiar' ),
        'fields' => array(
          array(
            'id'    => 'sidebar_name',
            'type'  => 'text',
            'title' => esc_html__( 'Sidebar Name', 'caspiar' ),
          ),
          array(
            'id'    => 'sidebar_desc',
            'type'  => 'text',
            'title' => esc_html__( 'Custom Description', 'caspiar' ),
          ),
        ),
         'default'             => array(
            array(
              'sidebar_name'   => esc_html__('Service Details', 'caspiar'),
              'sidebar_desc'   => esc_html__('Service details widget', 'caspiar'),
            ),
          ),

      ),

    )
  ) );

  // Translation
  CSF::createSection( $prefix, array(
    'parent'   => 'misc_section',
    'name'     => 'theme_translation_section',
    'title'    => esc_html__( 'Translation', 'caspiar' ),
    'icon'     => 'fa fa-language',
    'fields'   => array(

      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Common Texts', 'caspiar' )
      ),
      array(
        'id'          => 'read_more_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Read More Text', 'caspiar' ),
      ),
       array(
        'id'          => 'author_by_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Author By Text', 'caspiar' ),
      ),
      array(
        'id'          => 'case_studies_read_more',
        'type'        => 'text',
        'title'       => esc_html__( 'Case Studies Read More', 'caspiar' ),
      ),
      array(
        'id'          => 'share_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Share Text', 'caspiar' ),
      ),
      array(
        'id'          => 'share_on_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Share On Tooltip Text', 'caspiar' ),
      ),
      array(
        'id'          => 'post_comment_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Post Comment Text [Submit Button]', 'caspiar' ),
      ),
      array(
        'type'    => 'submessage',
        'style'   => 'info',
        'content' => esc_html__( 'Filter All Texts', 'caspiar' )
      ),
      array(
        'id'          => 'all_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Filter All Text (Portfolio)', 'caspiar' ),
      ),
      array(
        'id'          => 'case_all_text',
        'type'        => 'text',
        'title'       => esc_html__( 'Filter All Text (Case Studies)', 'caspiar' ),
      ),

    )
  ) );

  // Backup
  CSF::createSection( $prefix, array(
    'name'     => 'backup_section',
    'title'    => 'Backup',
    'icon'     => 'fa fa-shield',
    'fields' => array(

      // Site Logo
      array(
        'type'    => 'submessage',
        'style'   => 'warning',
        'content' => esc_html__( 'You can save your current options. Download a Backup and Import.', 'caspiar' ),
      ),
      array(
        'type'    => 'backup',
      ),

    )
  ) );

}
